@@ -299,6 +299,7 @@ enum {
   SPVM_OP_C_FLAG_ARRAY_ACCESS_STRING = 2,
   SPVM_OP_C_FLAG_ARRAY_ACCESS_UNWEAKEN = 4,
   SPVM_OP_C_FLAG_ARRAY_ACCESS_ISWEAK = 8,
+  SPVM_OP_C_FLAG_ARRAY_ACCESS_PARENT_IS_FIELD_ACCESS = 16,
 };
 
 enum {
@@ -308,7 +309,7 @@ enum {
 
 enum {
   // ARRAY_INIT flag
-  SPVM_OP_C_FLAG_ARRAY_MOVE_IS_KEY_VALUES_ZERO = 1,
+  SPVM_OP_C_FLAG_ARRAY_INIT_IS_KEY_VALUES = 1,
 };
 
 enum {
@@ -359,6 +360,8 @@ struct spvm_op {
   int8_t is_assigned_to_var;
   int8_t no_need_check;
   int8_t free_tmp_vars;
+  int8_t allow_narrowing_conversion;
+  int8_t original_id;
 };
 
 SPVM_OP* SPVM_OP_build_operator_statement(SPVM_COMPILER* compiler, SPVM_OP* op_value_op);
