@@ -110,31 +110,25 @@ enum {
   SPVM_OPCODE_C_ID_ENTER_SCOPE,
   SPVM_OPCODE_C_ID_PUSH_MORTAL,
   SPVM_OPCODE_C_ID_LEAVE_SCOPE,
-  SPVM_OPCODE_C_ID_INIT_BYTE,
-  SPVM_OPCODE_C_ID_INIT_SHORT,
-  SPVM_OPCODE_C_ID_INIT_INT,
-  SPVM_OPCODE_C_ID_INIT_LONG,
-  SPVM_OPCODE_C_ID_INIT_FLOAT,
-  SPVM_OPCODE_C_ID_INIT_DOUBLE,
-  SPVM_OPCODE_C_ID_INIT_OBJECT,
-  SPVM_OPCODE_C_ID_INIT_MULNUM_BYTE,
-  SPVM_OPCODE_C_ID_INIT_MULNUM_SHORT,
-  SPVM_OPCODE_C_ID_INIT_MULNUM_INT,
-  SPVM_OPCODE_C_ID_INIT_MULNUM_LONG,
-  SPVM_OPCODE_C_ID_INIT_MULNUM_FLOAT,
-  SPVM_OPCODE_C_ID_INIT_MULNUM_DOUBLE,
   SPVM_OPCODE_C_ID_MOVE_CONSTANT_BYTE,
   SPVM_OPCODE_C_ID_MOVE_CONSTANT_INT,
   SPVM_OPCODE_C_ID_MOVE_CONSTANT_LONG,
   SPVM_OPCODE_C_ID_MOVE_CONSTANT_FLOAT,
   SPVM_OPCODE_C_ID_MOVE_CONSTANT_DOUBLE,
   SPVM_OPCODE_C_ID_MOVE_BYTE,
+  SPVM_OPCODE_C_ID_MOVE_BYTE_ZERO,
   SPVM_OPCODE_C_ID_MOVE_SHORT,
+  SPVM_OPCODE_C_ID_MOVE_SHORT_ZERO,
   SPVM_OPCODE_C_ID_MOVE_INT,
+  SPVM_OPCODE_C_ID_MOVE_INT_ZERO,
   SPVM_OPCODE_C_ID_MOVE_LONG,
+  SPVM_OPCODE_C_ID_MOVE_LONG_ZERO,
   SPVM_OPCODE_C_ID_MOVE_FLOAT,
+  SPVM_OPCODE_C_ID_MOVE_FLOAT_ZERO,
   SPVM_OPCODE_C_ID_MOVE_DOUBLE,
+  SPVM_OPCODE_C_ID_MOVE_DOUBLE_ZERO,
   SPVM_OPCODE_C_ID_MOVE_OBJECT,
+  SPVM_OPCODE_C_ID_MOVE_OBJECT_UNDEF,
   SPVM_OPCODE_C_ID_MOVE_OBJECT_WITH_TYPE_CHECKING,
   SPVM_OPCODE_C_ID_MOVE_OBJECT_CHECK_READ_ONLY,
   SPVM_OPCODE_C_ID_MOVE_OBJECT_NO_INC,
@@ -342,11 +336,17 @@ enum {
   SPVM_OPCODE_C_ID_SET_MULNUM_FIELD_FLOAT,
   SPVM_OPCODE_C_ID_SET_MULNUM_FIELD_DOUBLE,
   SPVM_OPCODE_C_ID_MOVE_MULNUM_BYTE,
+  SPVM_OPCODE_C_ID_MOVE_MULNUM_BYTE_ZERO,
   SPVM_OPCODE_C_ID_MOVE_MULNUM_SHORT,
+  SPVM_OPCODE_C_ID_MOVE_MULNUM_SHORT_ZERO,
   SPVM_OPCODE_C_ID_MOVE_MULNUM_INT,
+  SPVM_OPCODE_C_ID_MOVE_MULNUM_INT_ZERO,
   SPVM_OPCODE_C_ID_MOVE_MULNUM_LONG,
+  SPVM_OPCODE_C_ID_MOVE_MULNUM_LONG_ZERO,
   SPVM_OPCODE_C_ID_MOVE_MULNUM_FLOAT,
+  SPVM_OPCODE_C_ID_MOVE_MULNUM_FLOAT_ZERO,
   SPVM_OPCODE_C_ID_MOVE_MULNUM_DOUBLE,
+  SPVM_OPCODE_C_ID_MOVE_MULNUM_DOUBLE_ZERO,
   SPVM_OPCODE_C_ID_GET_MULNUM_ARRAY_BYTE,
   SPVM_OPCODE_C_ID_GET_MULNUM_ARRAY_SHORT,
   SPVM_OPCODE_C_ID_GET_MULNUM_ARRAY_INT,
