@@ -55,7 +55,7 @@ SPVM_COMPILER* SPVM_COMPILER_new() {
   SPVM_ALLOCATOR* allocator = SPVM_ALLOCATOR_new();
   compiler->allocator = allocator;
   
-  compiler->bufptr = "";
+  compiler->ch_ptr = "";
   
   compiler->constant_strings = SPVM_LIST_new_list_permanent(compiler->allocator, 128);
   compiler->constant_string_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 128);
@@ -75,9 +75,9 @@ SPVM_COMPILER* SPVM_COMPILER_new() {
   compiler->class_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
   compiler->class_vars = SPVM_LIST_new_list_permanent(compiler->allocator, 0);
   compiler->opcode_array = SPVM_OPCODE_ARRAY_new(compiler);
-  compiler->class_source_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
+  compiler->source_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
   compiler->switch_infos = SPVM_LIST_new_list_permanent(compiler->allocator, 0);
-  compiler->not_found_class_class_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
+  compiler->not_found_class_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
   
   // Add basic types
   SPVM_COMPILER_add_basic_types(compiler);
@@ -85,94 +85,94 @@ SPVM_COMPILER* SPVM_COMPILER_new() {
   // Add Bool source
   {
     const char* class_name = "Bool";
-    const char* class_source = "class Bool {\n  INIT {\n    $TRUE = new Bool;\n    $TRUE->{value} = 1;\n    $FALSE = new Bool;\n    $FALSE->{value} = 0;\n  }\n  \n  our $TRUE : ro Bool;\n  our $FALSE : ro Bool;\n  has value : ro int;\n}";
-    SPVM_COMPILER_add_class_source(compiler, class_name, class_source, strlen(class_source));
+    const char* source = "class Bool {\n  INIT {\n    $TRUE = new Bool;\n    $TRUE->{value} = 1;\n    $FALSE = new Bool;\n    $FALSE->{value} = 0;\n  }\n  \n  our $TRUE : ro Bool;\n  our $FALSE : ro Bool;\n  has value : ro int;\n}";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
   }
   
   // Add Error source
   {
     const char* class_name = "Error";
-    const char* class_source = "class Error;";
-    SPVM_COMPILER_add_class_source(compiler, class_name, class_source, strlen(class_source));
+    const char* source = "class Error;";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
   }
   
   // Add Error::System source
   {
     const char* class_name = "Error::System";
-    const char* class_source = "class Error::System;";
-    SPVM_COMPILER_add_class_source(compiler, class_name, class_source, strlen(class_source));
+    const char* source = "class Error::System;";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
   }
   
   // Add Error::NotSupported source
   {
     const char* class_name = "Error::NotSupported";
-    const char* class_source = "class Error::NotSupported;";
-    SPVM_COMPILER_add_class_source(compiler, class_name, class_source, strlen(class_source));
+    const char* source = "class Error::NotSupported;";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
   }
   
   // Add Byte source
   {
     const char* class_name = "Byte";
-    const char* class_source = "class Byte {\n  has value : ro byte;\n  static method new : Byte ($value : int) {\n    my $self = new Byte;\n    $self->{value} = (byte)$value;\n    return $self;\n  }\n}";
-    SPVM_COMPILER_add_class_source(compiler, class_name, class_source, strlen(class_source));
+    const char* source = "class Byte {\n  has value : ro byte;\n  static method new : Byte ($value : int) {\n    my $self = new Byte;\n    $self->{value} = (byte)$value;\n    return $self;\n  }\n}";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
   }
   
   // Add Short source
   {
     const char* class_name = "Short";
-    const char* class_source = "class Short {\n  has value : ro short;\n  static method new : Short ($value : int) {\n    my $self = new Short;\n    $self->{value} = (short)$value;\n    return $self;\n  }\n}";
-    SPVM_COMPILER_add_class_source(compiler, class_name, class_source, strlen(class_source));
+    const char* source = "class Short {\n  has value : ro short;\n  static method new : Short ($value : int) {\n    my $self = new Short;\n    $self->{value} = (short)$value;\n    return $self;\n  }\n}";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
   }
   
   // Add Int source
   {
     const char* class_name = "Int";
-    const char* class_source = "class Int {\n  has value : ro int;\n  static method new : Int ($value : int) {\n    my $self = new Int;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
-    SPVM_COMPILER_add_class_source(compiler, class_name, class_source, strlen(class_source));
+    const char* source = "class Int {\n  has value : ro int;\n  static method new : Int ($value : int) {\n    my $self = new Int;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
   }
   
   // Add Long source
   {
     const char* class_name = "Long";
-    const char* class_source = "class Long {\n  has value : ro long;\n  static method new : Long ($value : long) {\n    my $self = new Long;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
-    SPVM_COMPILER_add_class_source(compiler, class_name, class_source, strlen(class_source));
+    const char* source = "class Long {\n  has value : ro long;\n  static method new : Long ($value : long) {\n    my $self = new Long;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
   }
   
   // Add Float source
   {
     const char* class_name = "Float";
-    const char* class_source = "class Float {\n  has value : ro float;\n  static method new : Float ($value : float) {\n    my $self = new Float;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
-    SPVM_COMPILER_add_class_source(compiler, class_name, class_source, strlen(class_source));
+    const char* source = "class Float {\n  has value : ro float;\n  static method new : Float ($value : float) {\n    my $self = new Float;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
   }
   
   // Add Double source
   {
     const char* class_name = "Double";
-    const char* class_source = "class Double {\n  has value : ro double;\n  static method new : Double ($value : double) {\n    my $self = new Double;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
-    SPVM_COMPILER_add_class_source(compiler, class_name, class_source, strlen(class_source));
+    const char* source = "class Double {\n  has value : ro double;\n  static method new : Double ($value : double) {\n    my $self = new Double;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
   }
   
   // Add CommandInfo source
   {
     const char* class_name = "CommandInfo";
-    const char* class_source = "class CommandInfo {\n  our $PROGRAM_NAME : ro string;\n  our $ARGV : ro string[];\n  our $BASE_TIME : ro long;\n  }";
-    SPVM_COMPILER_add_class_source(compiler, class_name, class_source, strlen(class_source));
+    const char* source = "class CommandInfo {\n  our $PROGRAM_NAME : ro string;\n  our $ARGV : ro string[];\n  our $BASE_TIME : ro long;\n  }";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
   }
   
   // Add Address source
   {
     const char* class_name = "Address";
-    const char* class_source = "class Address : pointer {\n  static method new : Address () {\n    my $self = new Address;\n    return $self;\n  }\n}";
-    SPVM_COMPILER_add_class_source(compiler, class_name, class_source, strlen(class_source));
+    const char* source = "class Address : pointer {\n  static method new : Address () {\n    my $self = new Address;\n    return $self;\n  }\n}";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
   }
   
   return compiler;
 }
 
-void SPVM_COMPILER_add_class_source(SPVM_COMPILER* compiler, const char* class_name, const char* class_source, int32_t length) {
-  SPVM_STRING_BUFFER* class_source_buffer = SPVM_STRING_BUFFER_new(compiler->allocator, length, SPVM_ALLOCATOR_C_ALLOC_TYPE_PERMANENT);
-  SPVM_STRING_BUFFER_add_len(class_source_buffer, (char*)class_source, strlen(class_source));
-  SPVM_HASH_set(compiler->class_source_symtable, class_name, strlen(class_name), (void*)class_source_buffer);
+void SPVM_COMPILER_add_source(SPVM_COMPILER* compiler, const char* class_name, const char* source, int32_t length) {
+  SPVM_STRING_BUFFER* source_buffer = SPVM_STRING_BUFFER_new(compiler->allocator, length, SPVM_ALLOCATOR_C_ALLOC_TYPE_PERMANENT);
+  SPVM_STRING_BUFFER_add_len(source_buffer, (char*)source, strlen(source));
+  SPVM_HASH_set(compiler->source_symtable, class_name, strlen(class_name), (void*)source_buffer);
 }
 
 void SPVM_COMPILER_add_basic_type(SPVM_COMPILER* compiler, int32_t basic_type_id) {
@@ -318,7 +318,7 @@ int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* class_name) {
     }
     else {
       // Check syntax
-      SPVM_OP_CHECKER_check(compiler);
+      SPVM_AST_CHECKER_check(compiler);
       if (SPVM_COMPILER_get_error_messages_length(compiler) > 0) {
         error_code = 3;
       }
